#!/bin/sh

# Arguments.
host=$1
port=$2

# Configureation section.
: ${DIALOG=dialog}              # Taken from an example dialog script.
myname="`basename $0`"          # This scripts name.
telnetcmd="/usr/bin/telnet"     # The command to telnet with.
defaultport="23"                # The default telnet port.
sshcmd="/usr/bin/ssh"           # The SSH command.
username="$USER"                # Default username for SSH.

# Make sure there is a host.
if [ ! "$host" ] ; then
    cat <<EOHELP
Usage: $myname [HOST] [PORT]
w3m Telnet/SSH selector

This is a small shell script intended to be uses with the web browser w3m.
Please see http://w3m.sourceforge.net/index.en.html in english or
http://w3m.sourceforge.net/index.ja.html in japanese for help.
EOHELP
    exit 1
fi

# We can let the port slide since there is a sensible default.
if [ ! "$port" ] ; then
    port=$defaultport
fi

# This telnets out.
telnet(){
    $telnetcmd $host $port
    exit $?
}

# If the port is not the default telnet out.
if [ "$port" != "$defaultport" ] ; then
    telnet
fi

# Ask if they want to use SSH.
$DIALOG --title "Use SSH?" \
        --yesno "You are telneting to '$host'.\n
Telnet is a very insecure protocol. 
SSH is a very secure protocol but may not be supported by '$host'. 
Would you like to use SSH instead?" 0 0

retval=$?

if [ $retval != "0" ] ; then
    telnet
fi

echo "Good choice."

# Prompt for the user name to use.
tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/test$$
trap "rm -f $tempfile" 0 1 2 5 15

$DIALOG --title "SSH User Name" --clear \
        --inputbox "Please enter the user name to SSH to '$host' as." \
        0 0 $username 2> $tempfile

retval=$?

if [ $retval == "0" ] ; then
    username=`cat $tempfile`
fi

clear
echo "SSHing to '$host' as '$username'"
$sshcmd -l $username $host

echo "Please press enter to continue..."
read retval
